<line class="svg-stroke-primary" x1="82.383" y1="41.576" x2="82.383" y2="66.155" fill="none" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line class="svg-stroke-primary" x1="17.617" y1="50.192" x2="17.617" y2="66.155" fill="none" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line class="svg-stroke-primary" x1="55.948" y1="27.121" x2="39.986" y2="27.121" fill="none" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<polyline class="svg-stroke-primary"
          points="77.684 53.303 69.678 53.303 69.678 46.021 60.833 37.176 37.042 37.176 29.467 44.751 29.467 72.879 56.008 72.879 63.647 65.24 69.517 65.24 69.517 55.027"
          fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<line class="svg-stroke-primary" x1="17.617" y1="58.173" x2="29.467" y2="58.173" fill="none" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line class="svg-stroke-primary" x1="47.967" y1="27.121" x2="47.967" y2="37.176" fill="none" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>