<path d="M66.3,29.6A16.3,16.3,0,1,1,50,13.4,16.3,16.3,0,0,1,66.3,29.6Z"
      fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M50,58.1A28.6,28.6,0,0,0,21.5,86.6h57A28.6,28.6,0,0,0,50,58.1Z" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
