<path d="M82.1,82.1,60.7,60.7m7.1-17.8a25,25,0,1,1-24.9-25A24.8,24.8,0,0,1,67.8,42.9Z" fill="none"
      class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M42.9,32.2V42.9m0,0V53.6m0-10.7H53.6m-10.7,0H32.2" fill="none" class="svg-stroke-primary"
      stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
