<polygon points="16.9 48.4 16.9 48.5 16.8 48.4 16.9 48.4" class="svg-fill-primary"/>
<polygon points="16.9 48.4 16.9 48.5 16.8 48.4 16.9 48.4" class="svg-fill-primary"/>
<path d="M59.5,51.6l18.9-9.2s-1.8,13.2,7.1,17.9" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M84.7,27.3s-7,4-6.4,14.5L59.5,51.1l-3.6-8.2L47.3,23.6H32V40.2H23.9V51.3h0a9.4,9.4,0,0,0-9.4,9.4V67a9.4,9.4,0,0,0,9.4,9.4H51.2A9.4,9.4,0,0,0,60.6,67V55.3"
      fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<line x1="23.9" y1="51.3" x2="59.5" y2="51.1" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="26.3" y1="63.8" x2="26.3" y2="63.8" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="37.3" y1="63.8" x2="37.3" y2="63.8" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="48.3" y1="63.8" x2="48.3" y2="63.8" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
