{% extends 'snowebsvg/common/builders/line.html' %}

{% block builder_base %}
    {% include 'snowebsvg/collections/heroicons/bars/_base.html' %}
{% endblock %}

{% block builder_hover %}
    {% include 'snowebsvg/collections/heroicons/bars/_base-hover.html' %}
{% endblock %}
