<line x1="14.3" y1="53.3" x2="85.7" y2="53.3" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M20.9,53.3S21,26.4,47.2,25.6c0,0-1.2-5.1,2.8-5.3s2.6,5,2.6,5,26.2.3,26.7,28" fill="none"
      class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M67.7,57.5s-6,10.3-5.7,12.3-.1,9.9-.1,9.9H52.2L32.3,62.3s-3-3.4-2.4-4.8" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
