{% extends 'snowebsvg/common/svg.html' %}
{% load svg_utils %}

{% block svg_viewbox %}0 0 1920 1920{% endblock %}
{% block svg_aspect_ratio %}xMidYMid slice{% endblock %}

{% block svg_content %}
    {% unique_id as id %}
    <defs>
        <pattern id="unit-{{ id }}" x="0" y="0" width="48" height="48"
                 patternUnits="userSpaceOnUse">
            <path class="svg-fill-primary" d="M12 0h18v6h6v6h6v18h-6v6h-6v6H12v-6H6v-6H0V12h6V6h6V0zm12 6h-6v6h-6v6H6v6h6v6h6v6h6v-6h6v-6h6v-6h-6v-6h-6V6zm-6 12h6v6h-6v-6zm24 24h6v6h-6v-6z"/>
        </pattern>
    </defs>
    <rect width="1920" height="1920" fill="url(#unit-{{ id }})"></rect>
{% endblock %}
