<path d="M46.5,17.3A32.8,32.8,0,1,0,82.7,53.5H46.5Z" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M81,39H61V19A32.3,32.3,0,0,1,81,39Z" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
