{% extends 'snowebsvg/common/svg.html' %}

{% block svg_viewbox %}0 0 1920 169.18{% endblock %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <polygon class="svg-fill-primary"
             points="0 0 105.82 125.19 440.79 0 960 118.43 1445.72 54.14 1920 169.18 0 169.18 0 0">
    </polygon>
{% endblock %}
