{% extends 'snowebsvg/common/svg.html' %}

{% block svg_viewbox %}0 0 1920 336.41{% endblock %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <polygon class="svg-fill-primary"
             points="0 336.41 1920 336.41 1920 244.45 1691.29 278.02 1382.06 175.89 562.18 272.35 0 0 0 336.41">
    </polygon>
{% endblock %}
