<line x1="38" y1="82.3" x2="63.4" y2="82.3" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<polyline points="50.4 82.3 50.4 54.1 79 19.2 21 19.2 50 53.7" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="8"/>
<line x1="32.5" y1="32.6" x2="68" y2="32.6" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
