{% extends 'snowebsvg/common/svg.html' %}

{% load svg_utils %}
{% block svg_viewbox %}0 0 1920 581.63{% endblock %}
{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <polygon {% variant_manager variant 'attrs' %}
            class="svg-fill-primary"
            points="0 581.63 1920 0 1920 104.55 0 581.63">
    </polygon>
    <polygon class="svg-fill-primary" points="0 581.63 1920 581.63 1920 104.55 0 581.63"></polygon>
{% endblock %}
