{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <rect x="18" y="22" width="16" height="56.08" rx="4" class="svg-fill-primary"/>
    <rect x="42" y="22" width="16" height="56.08" rx="4" class="svg-fill-primary"/>
    <rect x="66" y="22" width="16" height="56.08" rx="4" class="svg-fill-primary"/>
{% endblock %}
