{% extends 'snowebsvg/common/svg.html' %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <polygon class="svg-fill-primary" points="0 0, 100 0, 0 100"></polygon>
{% endblock %}
