{% extends 'snowebsvg/common/svg.html' %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <path class="svg-fill-primary"
          d="m 0,100 v -100 h 100 v 100 c 0,0 0,-100 -50,-100 -50,0 -50,100 -50,100 z"/>
{% endblock %}
