<circle cx="50.2" cy="61.8" r="15.6" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="19"/>
<path d="M34.6,61.8S29.3,35.2,58.3,22.6" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
      stroke-width="19"/>
