<path d="M84.35,26.85v23.5s-14-25.9-34.4-24.2" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="84.35" y1="85.35" x2="84.35" y2="26.85" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M15.65,26.85v23.5s13.9-25.9,34.3-24.2" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="15.65" y1="85.35" x2="15.65" y2="26.85" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="15.65" y1="79.35" x2="84.35" y2="79.35" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<polyline points="65.35 23.05 65.35 79.35 49.95 79.35" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="8"/>
<polyline points="34.65 23.05 34.65 79.35 49.95 79.35 49.95 14.65" fill="none" class="svg-stroke-primary"
          stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<circle cx="15.65" cy="23.25" r="3.7" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="8"/>
<circle cx="84.35" cy="23.25" r="3.7" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="8"/>
