{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <circle cx="50" cy="26" r="8" class="svg-fill-primary"/>
    <circle cx="50" cy="50" r="8" class="svg-fill-primary"/>
    <circle cx="50" cy="74" r="8" class="svg-fill-primary"/>
{% endblock %}
