{% extends 'snowebsvg/common/svg.html' %}

{% block svg_viewbox %}0 0 1920 98.37{% endblock %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <path class="svg-fill-primary"
          d="M1920,98.37H0S111.09-20.47,298.89,3.09,647.65,77.45,808.61,35.62,1802.68,32.63,1920,98.37Z"
          transform="translate(0 0)">
    </path>
{% endblock %}
