<path d="M49.291,22.491,16.861,78.662H83.139L50.709,22.491A.819.819,0,0,0,49.291,22.491Z" fill="none"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<polyline points="34.583 47.967 45.546 57.221 51.894 47.967 70.761 57.221" fill="none" class="svg-stroke-primary"
          stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>