<ellipse cx="50" cy="63.1" rx="16" ry="12.9" fill="none" class="svg-stroke-primary" stroke-linecap="round"
         stroke-linejoin="round" stroke-width="19"/>
<ellipse cx="50" cy="36.9" rx="14.1" ry="12.9" fill="none" class="svg-stroke-primary" stroke-linecap="round"
         stroke-linejoin="round" stroke-width="19"/>
