<circle cx="49.8" cy="38.2" r="15.6" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="19"/>
<path d="M65.4,38.2s5.3,26.6-23.7,39.2" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
      stroke-width="19"/>
