<path d="M64.1,12.5h-29S22.9,45.1,32.8,55.1s23.5,11.1,34.2,0S64.1,12.5,64.1,12.5Z" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<line x1="50" y1="63" x2="50" y2="87.5" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
      stroke-width="8"/>
<line x1="34.4" y1="87.5" x2="65.6" y2="87.5" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="29.1" y1="38.5" x2="70.9" y2="38.5" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
