{% extends 'snowebsvg/collections/separator_bottom/wave/3.html' %}
{% load svg_utils %}

{% block svg_content %}
    <g transform="scale (1, -1)" transform-origin="center">
        {{ block.super }}
    </g>
{% endblock %}
