{% extends 'snowebsvg/common/svg.html' %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <path class="svg-fill-primary" d="m 0,100 c 0,-100 100,-100 100,-100 H 0 Z"/>
{% endblock %}
