{% extends 'snowebsvg/common/svg.html' %}

{% load svg_utils %}
{% block svg_viewbox %}0 0 1920.03 420.61{% endblock %}
{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <path class="svg-fill-primary"
            {% variant_manager variant 'attrs' %}
          d="M1920,420.61H0S18.53,2.05,587.58,129.09c566.79,126.52,611.61,247,908.39,96.75C1779.28,82.42,1920,420.61,1920,420.61Z"
          transform="translate(0.03)"></path>
    <circle {% variant_manager variant 'attrs' %}
            class="svg-fill-primary"
            cx="1735.28" cy="40.89"
            r="40.89"></circle>
    <circle {% variant_manager variant 'attrs' %}
            class="svg-fill-primary"
            cx="1799.4"
            cy="130.4"
            r="24.28"></circle>
    <circle {% variant_manager variant 'attrs' %}
            class="svg-fill-primary"
            cx="1822.78"
            cy="73.13"
            r="11.13"></circle>
    <circle {% variant_manager variant 'attrs' %}
            class="svg-fill-primary"
            cx="76.1"
            cy="109.72"
            r="19.37"></circle>
    <path class="svg-fill-primary"
          d="M1920,420.61H0S128.72,70,705.48,137.8s643.15,244.74,940,94.46C1928.72,88.84,1920,420.61,1920,420.61Z"
          transform="translate(0.03)"></path>
{% endblock %}
