<circle cx="68.5" cy="71.6" r="7.2" fill="none" class="svg-stroke-primary" stroke-linecap="round"
        stroke-linejoin="round"
        stroke-width="8"/>
<circle cx="28.8" cy="71.6" r="7.2" fill="none" class="svg-stroke-primary" stroke-linecap="round"
        stroke-linejoin="round"
        stroke-width="8"/>
<path d="M15.7,62.5H84.3V48.2A15.6,15.6,0,0,0,68.7,32.7H65.5V57.9" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<rect x="15.7" y="24.6" width="37.4" height="25.86" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
