{% extends 'snowebsvg/common/svg.html' %}
{% load svg_utils %}

{% block svg_viewbox %}0 0 40 1{% endblock %}
{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    {% unique_id as id %}
    <defs>
        <pattern id="unit-{{ id }}" x="0" y="0" width="40" height="1"
                 patternUnits="userSpaceOnUse">
            <rect class="svg-fill-primary" fill-rule="evenodd" x="0" y="0" width="20" height="1"/>
        </pattern>
    </defs>
    <rect width="40" height="1" fill="url(#unit-{{ id }})"></rect>
{% endblock %}
