{% load svg_utils %}
{% unique_id as id %}
<clipPath id="clip-path-{{ id }}">
    <rect x="0" y="0" width="100" height="100" rx="15" ry="15"></rect>
</clipPath>

<g clip-path="url(#clip-path-{{ id }})">
    {% comment %}We transform here because of `stdDeviation` of blur{% endcomment %}
    {% if variant == 'glass' %}<g transform="{% scale 1 %}">{% endif %}
    <rect {% variant_manager variant 'attrs' %}
            class="svg-fill-tertiary"
            x="0"
            y="0"
            width="100"
            height="100"
            rx="15"
            ry="15"
    >
    </rect>
    {% if variant == 'glass' %}</g>{% endif %}
    <g transform="{% scale 1.45 %}">
        <circle {% variant_manager variant 'attrs' %}
                class="svg-fill-secondary svg-builder-circle"
                cx="50"
                cy="50"
                r="50">
        </circle>
    </g>
</g>
