{% extends 'snowebsvg/common/builders/rect.html' %}

{% block builder_base %}
    {% include 'snowebsvg/collections/heroicons/envelope/_base.html' %}
{% endblock %}

{% block builder_hover %}
    {% include 'snowebsvg/collections/heroicons/envelope/_base-hover.html' %}
{% endblock %}
