<line x1="83.8" y1="85" x2="16.2" y2="85" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<polyline points="22.65 85 48.05 15 77.35 85" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="8"/>
<line x1="33.95" y1="53.9" x2="64.35" y2="53.9" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="42.93" y1="29.11" x2="53.96" y2="29.11" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="25.55" y1="78" x2="74.15" y2="78" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
