{% extends 'snowebsvg/common/svg.html' %}

{% block svg_viewbox %}0 0 1920 346.8{% endblock %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <path class="svg-fill-primary" d="M1920,346.8H0S1920-320.83,1920,196.56Z"></path>
{% endblock %}
