<circle cx="30.06" cy="59.89" r="15.4" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="8"/>
<path d="M23.52,46V22H43.78l7.9,19.18H70.87S68.16,29.06,75.23,24c0,0-4.83,4.77-4.36,17.19l14.47,0v8.92l-7.06,6.92s-10.69-5.74-17,4.75h-16"
      fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<circle cx="72.85" cy="70.59" r="3.83" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="8"/>
