<circle cx="50" cy="55.236" r="25.468" fill="none" class="svg-stroke-primary" stroke-linecap="round"
        stroke-linejoin="round"
        stroke-width="8"/>
<path d="M44.544,54.715l17-10.114-11.6,16.02a4.085,4.085,0,0,1-6.616-4.792A4.146,4.146,0,0,1,44.544,54.715Z"
      class="svg-stroke-primary"/>
<line x1="57.981" y1="19.296" x2="42.019" y2="19.296" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="50" y1="19.296" x2="50" y2="29.351" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
