{{ start }} load svg {{ end }}

{% block content %}<a href="#" class="svg-trigger">
    {{ start }} svg_inline '{{ self.key_composer }}' '{{ theme }}' {{ width }} {{ height }}{% if variant %} '{{ variant }}'{% endif %} {{ end }}
</a>{% endblock %}