{% extends 'snowebsvg/common/svg.html' %}

{% block svg_viewbox %}0 0 1920 383{% endblock %}

{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <path class="svg-fill-primary" d="M0,0H1920s-128.75,350.62-705.51,282.81-643.15-244.74-940-94.46C-8.75,331.77,0,0,0,0Z"></path>
    <circle class="svg-fill-primary" cx="403" cy="256.5" r="40.89"></circle>
    <circle class="svg-fill-primary" cx="362.11" cy="358.72" r="24.28"></circle>
    <circle class="svg-fill-primary" cx="422.95" cy="347.59" r="11.13"></circle>
    <circle class="svg-fill-primary" cx="1798.98" cy="269.28" r="19.37"></circle>
{% endblock %}
