<path d="M76.6,60.7c-17.9-2-11.4-17.1-11.4-17.1-21-6.6-9.1-22.9-8.7-23.5a27,27,0,0,0-6.3-.7A29.1,29.1,0,1,0,76.6,60.7Z"
      fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<circle cx="38.8" cy="40.1" r="3.5" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="8"/>
<circle cx="38.8" cy="59.4" r="1.1" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="8"/>
<circle cx="56.5" cy="61.6" r="1.1" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="8"/>
<path d="M70.6,28.9s-.3,4.9-3.6,2.9S70.6,28.9,70.6,28.9Z" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M79.2,49.1s-2.7-1.2-2.8-2.8S81.1,41.1,79.2,49.1Z" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
