<path d="M59.9,50A9.9,9.9,0,1,1,50,40.1,9.9,9.9,0,0,1,59.9,50Z" fill="none" class="svg-stroke-primary"
      stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M18.4,50a33.1,33.1,0,0,1,63.2,0,33.1,33.1,0,0,1-63.2,0Z" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
