{% extends 'snowebsvg/common/svg.html' %}

{% load svg_utils %}

{% block svg_viewbox %}0 0 192 108{% endblock %}
{% block svg_aspect_ratio %}xMidYMid slice{% endblock %}

{% block svg_content %}
    <g opacity="0.15" transform="{% scale 2.25 x=96 y=54 %}">
        <circle class="svg-fill-primary svg-builder-circle svg-slow svg-keep"
                cx="96"
                cy="54"
                r="0">
        </circle>
    </g>
{% endblock %}
