<circle cx="50" cy="32.4" r="10.86" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="8"/>
<line x1="71.2" y1="87.4" x2="53.91" y2="42.53" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="50" y1="21.54" x2="50" y2="12.6" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<line x1="46.09" y1="42.53" x2="28.8" y2="87.4" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M23.5,61.4s29,25,53,0" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
      stroke-width="8"/>
