{% extends 'snowebsvg/common/svg.html' %}
{% load svg_utils %}

{% block svg_viewbox %}0 0 160 320{% endblock %}
{% block svg_aspect_ratio %}xMidYMid slice{% endblock %}

{% block svg_content %}
    {% unique_id as id %}
    <defs>
        <pattern id="unit-{{ id }}" x="0" y="0" width="16" height="32"
                 patternUnits="userSpaceOnUse">
            <path class="svg-fill-primary" fill-rule="evenodd"
                  d="M0 24h4v2H0v-2zm0 4h6v2H0v-2zm0-8h2v2H0v-2zM0 0h4v2H0V0zm0 4h2v2H0V4zm16 20h-6v2h6v-2zm0 4H8v2h8v-2zm0-8h-4v2h4v-2zm0-20h-6v2h6V0zm0 4h-4v2h4V4zm-2 12h2v2h-2v-2zm0-8h2v2h-2V8zM2 8h10v2H2V8zm0 8h10v2H2v-2zm-2-4h14v2H0v-2zm4-8h6v2H4V4zm0 16h6v2H4v-2zM6 0h2v2H6V0zm0 24h2v2H6v-2z"/>
        </pattern>
    </defs>
    <rect width="160" height="320" fill="url(#unit-{{ id }})"></rect>
{% endblock %}
