{% extends 'snowebsvg/common/svg.html' %}
{% load svg_utils %}

{% block svg_viewbox %}0 0 800 480{% endblock %}
{% block svg_aspect_ratio %}xMidYMid slice{% endblock %}

{% block svg_content %}
    {% unique_id as id %}
    <defs>
        <pattern id="unit-{{ id }}" x="0" y="0" width="20" height="12"
                 patternUnits="userSpaceOnUse">
            <path fill-rule="evenodd" class="svg-fill-primary"
                  d="M9.8 12L0 2.2V.8l10 10 10-10v1.4L10.2 12h-.4zm-4 0L0 6.2V4.8L7.2 12H5.8zm8.4 0L20 6.2V4.8L12.8 12h1.4zM9.8 0l.2.2.2-.2h-.4zm-4 0L10 4.2 14.2 0h-1.4L10 2.8 7.2 0H5.8z"/>
        </pattern>
    </defs>
    <rect width="800" height="480" fill="url(#unit-{{ id }})"></rect>
{% endblock %}
