{% extends 'snowebsvg/common/builders/circle-simplified.html' %}

{% load svg_utils %}

{% block builder_base %}
    {% include 'snowebsvg/collections/heroicons/view_boards/_base.html' %}
{% endblock %}
