{% extends 'snowebsvg/common/svg.html' %}

{% block svg_viewbox %}0 0 10 10{% endblock %}
{% block svg_aspect_ratio %}none{% endblock %}

{% block svg_content %}
    <rect class="svg-fill-primary" width="10" height="10"></rect>
{% endblock %}
