<path d="M53.6,32.2A14.3,14.3,0,1,1,39.3,18,14.2,14.2,0,0,1,53.6,32.2Z" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M39.3,57.1A21.3,21.3,0,0,0,18,78.4V82H60.7V78.4A21.3,21.3,0,0,0,39.3,57.1Z" fill="none"
      class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M82,50H60.7" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
      stroke-width="8"/>
