<text x="{% block text_x %}{% endblock %}"
      y="{% block text_y %}{% endblock %}"
      class="svg-fill-primary"
      font-family="ui-sans-serif, system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji'"
      font-weight="900"
      font-size="115">{% block text_content %}{% endblock %}</text>