{% load svg i18n %}<!-- {% trans 'WARNING This work includes material that may be protected as a trademark in some jurisdictions. If you want to use it, you have to ensure that you have the legal right to do so and that you do not infringe any trademark rights. The use of these trademarks does not indicate endorsement of the trademark holder by Snoweb SVG, nor vice versa. See the trademark owner for rules about appropriate use of their trademarks.' %} {% block link_terms %}{% endblock %} -->
{% svg_inline self theme width height variant grid %}