<polygon points="19 16 19 84 87 84 19 16" fill="none" class="svg-stroke-primary" stroke-linecap="round"
         stroke-linejoin="round" stroke-width="8"/>
<polyline points="19.5 69.5 32.5 69.5 32.5 82.5" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="8"/>
