<g>
    {% for usless in 'sssssssssss' %}
        <line opacity="0.1" class="svg-stroke-tertiary" x1="{{ forloop.counter0 }}0" y1="0" x2="{{ forloop.counter0 }}0" y2="100"></line>
    {% endfor %}
    {% for usless in 'sssssssssss' %}
        <line opacity="0.1" class="svg-stroke-tertiary" x1="0" y1="{{ forloop.counter0 }}0" x2="100" y2="{{ forloop.counter0 }}0"></line>
    {% endfor %}
</g>