<path d="M41.52,20.321S33.289,23,31.543,28.437s-3.808,14.009-.412,17.6S41.579,56.9,45.728,57.874" fill="none"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M17.505,41.1s3.7,4,10.741,3.787" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M22.876,22.486s2.806,5.4,7.459,5.951" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M58.48,20.321S66.711,23,68.457,28.437s3.808,14.009.412,17.6S58.421,56.9,54.272,57.874" fill="none"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M82.5,41.1s-3.7,4-10.741,3.787" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round"
      stroke-width="8"/>
<path d="M77.124,22.486s-2.806,5.4-7.459,5.951" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M41.435,44.893s-2.918,9.723,5.14,13.2,13.034-10.36,11.177-13.2" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M43.515,57.389s-5.379,2.329-1.886,9.025,2.667,12.421,6.622,13.2,5.12-5.435,5.9-7.667,7.516-9.025,1.186-15.43"
      fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M64.167,59.3s3.135,1.846,5.5-.193" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M36.1,58.977s-2.827,2.718-5.28,0" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>