<path d="M82.1,82.1,60.7,60.7m7.1-17.8a25,25,0,1,1-24.9-25A24.8,24.8,0,0,1,67.8,42.9Z" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M53.6,42.9H32.2" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
      stroke-width="8"/>
