{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <path d="M50,50V18A32,32,0,1,0,82,50Z" class="svg-fill-primary"/>
    <path d="M58,19V42H81A31.9,31.9,0,0,0,58,19Z" class="svg-fill-primary"/>
{% endblock %}
