<path d="M78.3,38.9s-34,31.9-41.9,38S11.8,88,21.7,66.4,35.4,27.2,44.5,32.6c16,9.6,14.9-10.4,13.1-14.6C54,9.5,80.5,24.3,78.3,38.9Z"
      fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M28.8,81s7,10.3,3.6-1.6" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
      stroke-width="8"/>
<path d="M38.9,74.8s9.9,9.1,2.9-2.5" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round"
      stroke-width="8"/>
<path d="M47.6,67.2s9.7,8.1,2.7-2.5" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round"
      stroke-width="8"/>
<path d="M66.9,49.3s9.9,9.1,2.9-2.5" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round"
      stroke-width="8"/>
<path d="M75.1,42s9.7,8,2.8-2.5" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
      stroke-width="8"/>
