{% extends 'snowebsvg/common/builders/basic.html' %}

{% load svg_utils %}

{% block svg_content %}
    {% include 'snowebsvg/common/builders/_circle.html' %}
    <g transform="{% scale 0.5 %}">
        {{ block.super }}
    </g>
{% endblock %}
