{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <rect x="18" y="18" width="64" height="18.3" rx="4.6" class="svg-fill-primary"/>
    <rect x="18" y="45.4" width="36.6" height="36.6" rx="4.6" class="svg-fill-primary"/>
    <rect x="63.7" y="45.4" width="18.3" height="36.6" rx="4.6" class="svg-fill-primary"/>
{% endblock %}
