<line x1="72.747" y1="79.448" x2="67.206" y2="36.375" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M67.787,46.047s-9.8,2.6-13.065-4.8l-5.21,20.359s8.741,1.056,8.657,5.09S55.4,81.688,55.4,81.688" fill="none"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<polyline points="49.512 61.608 40.844 59.001 34.159 81.584" fill="none" class="svg-stroke-primary"
          stroke-linecap="round"
          stroke-linejoin="round" stroke-width="8"/>
<path d="M54.722,41.249s-2.978-7.828-10.756-6.824S27.253,52,27.253,52" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<line x1="40.844" y1="59.001" x2="45.407" y2="35.001" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<circle cx="49.323" cy="21.929" r="3.618" fill="none" class="svg-stroke-primary" stroke-linecap="round"
        stroke-linejoin="round" stroke-width="8"/>
<line x1="45.407" y1="59.001" x2="50.5" y2="36.836" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>