{% load svg_utils %}
{% unique_id as id %}
<clipPath id="clip-path-{{ id }}">
    <circle cx="50" cy="50" r="50"></circle>
</clipPath>
{% if variant == 'glass' %}<g clip-path="url(#clip-path-{{ id }})" transform="{% scale 1 %}">{% endif %}
<circle {% variant_manager variant 'attrs' %}
        class="svg-fill-tertiary"
        cx="50"
        cy="50"
        r="50">
</circle>
<circle {% variant_manager variant 'attrs' %}
        class="svg-fill-secondary svg-builder-circle"
        cx="50"
        cy="50"
        r="50">
</circle>
{% if variant == 'glass' %}</g>{% endif %}