{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <rect x="18.3" y="50" width="15.8" height="27.73" rx="4" class="svg-fill-primary"/>
    <rect x="42.1" y="34.2" width="15.8" height="43.57" rx="4" class="svg-fill-primary"/>
    <rect x="65.8" y="22.3" width="15.8" height="55.45" rx="4" class="svg-fill-primary"/>
{% endblock %}
