{% load svg_utils %}
{% unique_id as id %}
<clipPath id="clip-path-{{ id }}">
    <rect x="0" y="95" width="100" height="5"></rect>
</clipPath>
<g clip-path="url(#clip-path-{{ id }})">
    <rect {% variant_manager variant 'attrs' %}
            class="svg-fill-tertiary"
            x="0"
            y="95"
            width="100"
            height="5">
    </rect>
    <g transform="translate(0, 50)">
        <circle {% variant_manager variant 'attrs' %}
                class="svg-fill-secondary svg-builder-circle"
                cx="50"
                cy="50"
                r="50">
        </circle>
    </g>
</g>
